   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
   ID   PROVIDER            MODULE                          FUNCTION NAME
-- @@stderr --
dtrace: failed to match :::profile: No probe matches description
dtrace: failed to match :::vmlinux: No probe matches description
dtrace: failed to match :::read: No probe matches description
dtrace: failed to match :::begin: No probe matches description
dtrace: failed to match ::vmlinux:read: No probe matches description
dtrace: failed to match :syscall:vmlinux:read: No probe matches description
dtrace: failed to match ::vmlinux:: No probe matches description
dtrace: failed to match fbt:des:des3_crunch_block:return: No probe matches description
dtrace: failed to match :readfoo*::: No probe matches description
dtrace: failed to match :::read: No probe matches description
